@@ -14,7 +14,7 @@ use Inline (
         ),
         ($ENV{LIBUSB_INCDIR} ? ( INC => "-I\"$ENV{LIBUSB_INCDIR}\"" ) : () ),
         NAME => 'Device::USB',
-        VERSION => '0.29',
+        VERSION => '0.33',
    );
 
 Inline->init();
@@ -45,11 +45,11 @@ Device::USB - Use libusb to access USB devices.
 
 =head1 VERSION
 
-Version 0.29
+Version 0.33
 
 =cut
 
-our $VERSION='0.29';
+our $VERSION=0.33;
 
 
 =head1 SYNOPSIS
@@ -212,7 +212,7 @@ Any other values are forced to the nearest endpoint.
 sub debug_mode
 {
     my ($class, $level) = @_;
-    
+
     lib_debug_mode( $level );
     return;
 }
@@ -515,7 +515,7 @@ interrupt_read.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006-2008 Houston Perl Mongers
+Copyright 2006-2009 Houston Perl Mongers
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -532,6 +532,11 @@ __C__
 
 static unsigned debugLevel = 0;
 
+unsigned DeviceUSBDebugLevel()
+{
+    return debugLevel;
+}
+
 void libusb_init()
 {
     usb_init();
@@ -552,52 +557,52 @@ void *libusb_get_busses()
     return usb_get_busses();
 }
 
-void *libusb_open(void *dev)
+void *libusb_open(char *dev)
 {
     return usb_open( (struct usb_device*)dev );
 }
 
-int libusb_close(void *dev)
+int libusb_close(char *dev)
 {
     return usb_close((usb_dev_handle *)dev);
 }
 
-int libusb_set_configuration(void *dev, int configuration)
+int libusb_set_configuration(char *dev, int configuration)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_set_configuration( %d )\n", configuration );
     }
     return usb_set_configuration((usb_dev_handle *)dev, configuration);
 }
 
-int libusb_set_altinterface(void *dev, int alternate)
+int libusb_set_altinterface(char *dev, int alternate)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_set_altinterface( %d )\n", alternate );
     }
     return usb_set_altinterface((usb_dev_handle *)dev, alternate);
 }
 
-int libusb_clear_halt(void *dev, unsigned int ep)
+int libusb_clear_halt(char *dev, unsigned int ep)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_clear_halt( %d )\n", ep );
     }
     return usb_clear_halt((usb_dev_handle *)dev, ep);
 }
 
-int libusb_reset(void *dev)
+int libusb_reset(char *dev)
 {
     return usb_reset((usb_dev_handle *)dev);
 }
 
-int libusb_get_driver_np(void *dev, int interface, char *name, unsigned int namelen)
+int libusb_get_driver_np(char *dev, int interface, char *name, unsigned int namelen)
 {
     int ret = 0;
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_get_driver_np( %d )\n", interface );
     }
@@ -610,9 +615,9 @@ int libusb_get_driver_np(void *dev, int interface, char *name, unsigned int name
 #endif
 }
 
-int libusb_detach_kernel_driver_np(void *dev, int interface)
+int libusb_detach_kernel_driver_np(char *dev, int interface)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_detach_kernel_driver_np( %d )\n", interface );
     }
@@ -623,32 +628,32 @@ int libusb_detach_kernel_driver_np(void *dev, int interface)
 #endif
 }
 
-int libusb_claim_interface(void *dev, int interface)
+int libusb_claim_interface(char *dev, int interface)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_claim_interface( %d )\n", interface );
     }
     return usb_claim_interface((usb_dev_handle *)dev, interface);
 }
 
-int libusb_release_interface(void *dev, int interface)
+int libusb_release_interface(char *dev, int interface)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_release_interface( %d )\n", interface );
     }
     return usb_release_interface((usb_dev_handle *)dev, interface);
 }
 
-void libusb_control_msg(void *dev, int requesttype, int request, int value, int index, char *bytes, int size, int timeout)
+void libusb_control_msg(char *dev, int requesttype, int request, int value, int index, char *bytes, int size, int timeout)
 {
     int i = 0;
     int retval = 0;
 
     Inline_Stack_Vars;
 
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_control_msg( %#04x, %#04x, %#04x, %#04x, %p, %d, %d )\n",
             requesttype, request, value, index, bytes, size, timeout
@@ -656,7 +661,7 @@ void libusb_control_msg(void *dev, int requesttype, int request, int value, int
         /* maybe need to add support for printing the bytes string. */
     }
     retval = usb_control_msg((usb_dev_handle *)dev, requesttype, request, value, index, bytes, size, timeout);
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "\t => %d\n",retval );
     }
@@ -683,9 +688,9 @@ void libusb_control_msg(void *dev, int requesttype, int request, int value, int
     Inline_Stack_Done;
 }
 
-int libusb_get_string(void *dev, int index, int langid, char *buf, size_t buflen)
+int libusb_get_string(char *dev, int index, int langid, char *buf, size_t buflen)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_get_string( %d, %d, %p, %u )\n",
             index, langid, buf, buflen
@@ -694,9 +699,9 @@ int libusb_get_string(void *dev, int index, int langid, char *buf, size_t buflen
     return usb_get_string((usb_dev_handle *)dev, index, langid, buf, buflen);
 }
 
-int libusb_get_string_simple(void *dev, int index, char *buf, size_t buflen)
+int libusb_get_string_simple(char *dev, int index, char *buf, size_t buflen)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_get_string_simple( %d, %p, %u )\n",
             index, buf, buflen
@@ -705,32 +710,32 @@ int libusb_get_string_simple(void *dev, int index, char *buf, size_t buflen)
     return usb_get_string_simple((usb_dev_handle *)dev, index, buf, buflen);
 }
 
-int libusb_get_descriptor(void *dev, unsigned char type, unsigned char index, void *buf, int size)
+int libusb_get_descriptor(char *dev, unsigned char type, unsigned char index, void *buf, int size)
 {
     return usb_get_descriptor((usb_dev_handle *)dev, type, index, buf, size);
 }
 
-int libusb_get_descriptor_by_endpoint(void *dev, int ep, unsigned char type, unsigned char index, void *buf, int size)
+int libusb_get_descriptor_by_endpoint(char *dev, int ep, unsigned char type, unsigned char index, void *buf, int size)
 {
     return usb_get_descriptor_by_endpoint((usb_dev_handle *)dev, ep, type, index, buf, size);
 }
 
-int libusb_bulk_write(void *dev, int ep, char *bytes, int size, int timeout)
+int libusb_bulk_write(char *dev, int ep, char *bytes, int size, int timeout)
 {
     return usb_bulk_write((usb_dev_handle *)dev, ep, bytes, size, timeout);
 }
 
-int libusb_bulk_read(void *dev, int ep, char *bytes, int size, int timeout)
+int libusb_bulk_read(char *dev, int ep, char *bytes, int size, int timeout)
 {
     return usb_bulk_read((usb_dev_handle *)dev, ep, bytes, size, timeout);
 }
 
-int libusb_interrupt_write(void *dev, int ep, char *bytes, int size, int timeout)
+int libusb_interrupt_write(char *dev, int ep, char *bytes, int size, int timeout)
 {
     return usb_interrupt_write((usb_dev_handle *)dev, ep, bytes, size, timeout);
 }
 
-int libusb_interrupt_read(void *dev, int ep, char *bytes, int size, int timeout)
+int libusb_interrupt_read(char *dev, int ep, char *bytes, int size, int timeout)
 {
     return usb_interrupt_read((usb_dev_handle *)dev, ep, bytes, size, timeout);
 }
@@ -873,7 +878,7 @@ static SV* build_interface( struct usb_interface_descriptor* inter )
     return sv_bless( newRV_noinc( (SV*)hash ),
         gv_stashpv( "Device::USB::DevInterface", 1 )
     );
-} 
+}
 
 /*
  * Given a pointer to an array of usb_interface structs, create a
